aind\_behavior\_curriculum.curriculum._BehaviorGraph
===================================================

.. currentmodule:: aind_behavior_curriculum.curriculum

.. autoclass:: _BehaviorGraph
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~_BehaviorGraph.__init__
      ~_BehaviorGraph.add_node
      ~_BehaviorGraph.add_transition
      ~_BehaviorGraph.construct
      ~_BehaviorGraph.copy
      ~_BehaviorGraph.dict
      ~_BehaviorGraph.from_orm
      ~_BehaviorGraph.json
      ~_BehaviorGraph.model_construct
      ~_BehaviorGraph.model_copy
      ~_BehaviorGraph.model_dump
      ~_BehaviorGraph.model_dump_json
      ~_BehaviorGraph.model_json_schema
      ~_BehaviorGraph.model_parametrized_name
      ~_BehaviorGraph.model_post_init
      ~_BehaviorGraph.model_rebuild
      ~_BehaviorGraph.model_validate
      ~_BehaviorGraph.model_validate_json
      ~_BehaviorGraph.model_validate_strings
      ~_BehaviorGraph.parse_file
      ~_BehaviorGraph.parse_obj
      ~_BehaviorGraph.parse_raw
      ~_BehaviorGraph.remove_node
      ~_BehaviorGraph.remove_node_transition
      ~_BehaviorGraph.schema
      ~_BehaviorGraph.schema_json
      ~_BehaviorGraph.see_node_transitions
      ~_BehaviorGraph.see_nodes
      ~_BehaviorGraph.set_transition_priority
      ~_BehaviorGraph.update_forward_refs
      ~_BehaviorGraph.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~_BehaviorGraph.model_computed_fields
      ~_BehaviorGraph.model_config
      ~_BehaviorGraph.model_extra
      ~_BehaviorGraph.model_fields
      ~_BehaviorGraph.model_fields_set
      ~_BehaviorGraph.nodes
      ~_BehaviorGraph.graph
   
   